( cd usr/lib ; rm -rf libsmokeqtxml.so.3 )
( cd usr/lib ; ln -sf libsmokeqtxml.so.3.0.0 libsmokeqtxml.so.3 )
( cd usr/lib ; rm -rf libsmokeqtxmlpatterns.so )
( cd usr/lib ; ln -sf libsmokeqtxmlpatterns.so.3 libsmokeqtxmlpatterns.so )
( cd usr/lib ; rm -rf libsmokeqtsvg.so.3 )
( cd usr/lib ; ln -sf libsmokeqtsvg.so.3.0.0 libsmokeqtsvg.so.3 )
( cd usr/lib ; rm -rf libsmokeqt3support.so.3 )
( cd usr/lib ; ln -sf libsmokeqt3support.so.3.0.0 libsmokeqt3support.so.3 )
( cd usr/lib ; rm -rf libsmokeqtdeclarative.so.3 )
( cd usr/lib ; ln -sf libsmokeqtdeclarative.so.3.0.0 libsmokeqtdeclarative.so.3 )
( cd usr/lib ; rm -rf libsmokeqtsvg.so )
( cd usr/lib ; ln -sf libsmokeqtsvg.so.3 libsmokeqtsvg.so )
( cd usr/lib ; rm -rf libsmokeqtopengl.so )
( cd usr/lib ; ln -sf libsmokeqtopengl.so.3 libsmokeqtopengl.so )
( cd usr/lib ; rm -rf libsmokeqtwebkit.so.3 )
( cd usr/lib ; ln -sf libsmokeqtwebkit.so.3.0.0 libsmokeqtwebkit.so.3 )
( cd usr/lib ; rm -rf libsmokeqtsql.so.3 )
( cd usr/lib ; ln -sf libsmokeqtsql.so.3.0.0 libsmokeqtsql.so.3 )
( cd usr/lib ; rm -rf libsmokeqtuitools.so )
( cd usr/lib ; ln -sf libsmokeqtuitools.so.3 libsmokeqtuitools.so )
( cd usr/lib ; rm -rf libsmokeqtdbus.so.3 )
( cd usr/lib ; ln -sf libsmokeqtdbus.so.3.0.0 libsmokeqtdbus.so.3 )
( cd usr/lib ; rm -rf libsmokeqsci.so )
( cd usr/lib ; ln -sf libsmokeqsci.so.3 libsmokeqsci.so )
( cd usr/lib ; rm -rf libsmokeqimageblitz.so )
( cd usr/lib ; ln -sf libsmokeqimageblitz.so.3 libsmokeqimageblitz.so )
( cd usr/lib ; rm -rf libsmokephonon.so )
( cd usr/lib ; ln -sf libsmokephonon.so.3 libsmokephonon.so )
( cd usr/lib ; rm -rf libsmokeqthelp.so )
( cd usr/lib ; ln -sf libsmokeqthelp.so.3 libsmokeqthelp.so )
( cd usr/lib ; rm -rf libsmokeqthelp.so.3 )
( cd usr/lib ; ln -sf libsmokeqthelp.so.3.0.0 libsmokeqthelp.so.3 )
( cd usr/lib ; rm -rf libsmokeqtdbus.so )
( cd usr/lib ; ln -sf libsmokeqtdbus.so.3 libsmokeqtdbus.so )
( cd usr/lib ; rm -rf libsmokeqsci.so.3 )
( cd usr/lib ; ln -sf libsmokeqsci.so.3.0.0 libsmokeqsci.so.3 )
( cd usr/lib ; rm -rf libsmokeqimageblitz.so.3 )
( cd usr/lib ; ln -sf libsmokeqimageblitz.so.3.0.0 libsmokeqimageblitz.so.3 )
( cd usr/lib ; rm -rf libsmokeqtsql.so )
( cd usr/lib ; ln -sf libsmokeqtsql.so.3 libsmokeqtsql.so )
( cd usr/lib ; rm -rf libsmokeqtuitools.so.3 )
( cd usr/lib ; ln -sf libsmokeqtuitools.so.3.0.0 libsmokeqtuitools.so.3 )
( cd usr/lib ; rm -rf libsmokeqtcore.so )
( cd usr/lib ; ln -sf libsmokeqtcore.so.3 libsmokeqtcore.so )
( cd usr/lib ; rm -rf libsmokeqt3support.so )
( cd usr/lib ; ln -sf libsmokeqt3support.so.3 libsmokeqt3support.so )
( cd usr/lib ; rm -rf libsmokeqttest.so )
( cd usr/lib ; ln -sf libsmokeqttest.so.3 libsmokeqttest.so )
( cd usr/lib ; rm -rf libsmokephonon.so.3 )
( cd usr/lib ; ln -sf libsmokephonon.so.3.0.0 libsmokephonon.so.3 )
( cd usr/lib ; rm -rf libsmokeqtopengl.so.3 )
( cd usr/lib ; ln -sf libsmokeqtopengl.so.3.0.0 libsmokeqtopengl.so.3 )
( cd usr/lib ; rm -rf libsmokeqtmultimedia.so.3 )
( cd usr/lib ; ln -sf libsmokeqtmultimedia.so.3.0.0 libsmokeqtmultimedia.so.3 )
( cd usr/lib ; rm -rf libsmokeqtgui.so )
( cd usr/lib ; ln -sf libsmokeqtgui.so.3 libsmokeqtgui.so )
( cd usr/lib ; rm -rf libsmokeqtxmlpatterns.so.3 )
( cd usr/lib ; ln -sf libsmokeqtxmlpatterns.so.3.0.0 libsmokeqtxmlpatterns.so.3 )
( cd usr/lib ; rm -rf libsmokeqtwebkit.so )
( cd usr/lib ; ln -sf libsmokeqtwebkit.so.3 libsmokeqtwebkit.so )
( cd usr/lib ; rm -rf libsmokeqtcore.so.3 )
( cd usr/lib ; ln -sf libsmokeqtcore.so.3.0.0 libsmokeqtcore.so.3 )
( cd usr/lib ; rm -rf libsmokeqtnetwork.so.3 )
( cd usr/lib ; ln -sf libsmokeqtnetwork.so.3.0.0 libsmokeqtnetwork.so.3 )
( cd usr/lib ; rm -rf libsmokeqtscript.so )
( cd usr/lib ; ln -sf libsmokeqtscript.so.3 libsmokeqtscript.so )
( cd usr/lib ; rm -rf libsmokeqtnetwork.so )
( cd usr/lib ; ln -sf libsmokeqtnetwork.so.3 libsmokeqtnetwork.so )
( cd usr/lib ; rm -rf libsmokeqtdeclarative.so )
( cd usr/lib ; ln -sf libsmokeqtdeclarative.so.3 libsmokeqtdeclarative.so )
( cd usr/lib ; rm -rf libsmokeqtgui.so.3 )
( cd usr/lib ; ln -sf libsmokeqtgui.so.3.0.0 libsmokeqtgui.so.3 )
( cd usr/lib ; rm -rf libsmokeqttest.so.3 )
( cd usr/lib ; ln -sf libsmokeqttest.so.3.0.0 libsmokeqttest.so.3 )
( cd usr/lib ; rm -rf libsmokeqtxml.so )
( cd usr/lib ; ln -sf libsmokeqtxml.so.3 libsmokeqtxml.so )
( cd usr/lib ; rm -rf libsmokeqtmultimedia.so )
( cd usr/lib ; ln -sf libsmokeqtmultimedia.so.3 libsmokeqtmultimedia.so )
( cd usr/lib ; rm -rf libsmokeqtscript.so.3 )
( cd usr/lib ; ln -sf libsmokeqtscript.so.3.0.0 libsmokeqtscript.so.3 )
